# trajectory_analysis_tools
Tools to analyze the decoded posterior probability of position

### Installation
```bash
pip install trajectory_analysis_tools
```
Or
```bash
conda install -c edeno trajectory_analysis_tools
```
Or
```bash
git clone <package.git>
python setup.py install
```

### Usage

### Developer Installation
1. Install miniconda (or anaconda) if it isn't already installed.
2. git clone https://github.com/edeno/trajectory_analysis_tools.git
2. Setup editiable package with dependencies
```bash
cd <package folder>
conda env create -f environment.yml
conda activate trajectory_analysis_tools
python setup.py develop
```
